#include <uuid.h>

int uuid_variant(const uuid_p p)
{
	int var;

	var = p->clock_seq;

	if ((var & 0x8000) == 0)
		return UUID_VARIANT_NCS;

	if ((var & 0x4000) == 0)
		return UUID_VARIANT_DCE;

	if ((var & 0x2000) == 0)
		return UUID_VARIANT_MICROSOFT;

	return UUID_VARIANT_OTHER;
}
